# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Nicholas Skaggs <nicholas.skaggs@canonical.com>


""" Tests for CurrencyConverter """

from __future__ import absolute_import

from testtools.matchers import Equals, NotEquals, Not, Is
from autopilot.matchers import Eventually

from CurrencyConverter.tests import CurrencyConverterTestCase


class TestCurrencyConverter(CurrencyConverterTestCase):
    """ Tests the CurrencyConverter page features """

    def setUp(self):
        super(TestCurrencyConverter, self).setUp()
        self.assertThat(
            self.ubuntusdk.get_qml_view().visible, Eventually(Equals(True)))

    def tearDown(self):
        super(TestCurrencyConverter, self).tearDown()

    """ Test if the currency rate is converted """
    def test_convert_currency(self):
        fromField = self.main_window.get_from_currency_field()
        toField = self.main_window.get_to_currency_field()
        fromCurrencyButton = self.main_window.get_from_currency_button()
        toCurrencyButton = self.main_window.get_to_currency_button()

        #store current values
        oldToValue = toField.text

        #input value to convert from
        self.pointing_device.click_object(fromField)
        self.keyboard.type('1')

        #store current values
        oldFromValue = fromField.text

        #verify fromField was updated and toField is still the same
        self.assertThat(toField.text, Eventually(NotEquals(oldToValue)))
        self.assertThat(fromField.text, Eventually(Equals(oldFromValue)))

        #store current values
        oldFromValue = fromField.text
        oldToValue = toField.text

        #change the from currency
        self.ubuntusdk.set_popup_value("popoverCurrencySelector", fromCurrencyButton, 'HUF')

        #verify fromField was updated and toField is still the same
        self.assertThat(fromField.text, Eventually(NotEquals(oldFromValue)))
        self.assertThat(toField.text, Eventually(Equals(oldToValue)))

        #store current values
        oldFromValue = fromField.text
        oldToValue = toField.text

        #change the to currency
        self.ubuntusdk.set_popup_value("popoverCurrencySelector", toCurrencyButton, 'BGN')

        #verify fromField is the same and toField is updated
        self.assertThat(fromField.text, Eventually(Equals(oldFromValue)))
        self.assertThat(toField.text, Eventually(NotEquals(oldToValue)))

    """ Test if the clear button clears the screen """
    def test_clear_button(self):
        clearButton = self.main_window.get_clear_button()
        fromField = self.main_window.get_from_currency_field()
        toField = self.main_window.get_to_currency_field()

        #click the clear button
        self.pointing_device.click_object(clearButton)

        #confirm fields have been wiped
        self.assertThat(fromField.text, Eventually(Equals('0.0')))
        self.assertThat(toField.text, Eventually(Equals('0.0')))
