import QtQuick 2.0
import Ubuntu.Components 0.1 // we need units.gu() here
import QtTest 1.0 // for TestCase
import "helpers.js" as Helpers
import "../../"

// Part 2 (read tst_currency.qml first if you haven't)

// This test creates a window and lets you interact with mouse and keyboard
// This time we wrap the TestCase into an Item because we need to display
// the CurrencyConverter.
// Just like before, you can run it with
// qmltestrunner -input tst_CurrencyConverter.qml
// Additionally you can open it in qmlscene:
// qmlscene tst_CurrencyConverter.qml

Item {
    width: units.gu(40)
    height: units.gu(30)

    // Create an instance of the QML element we want to test
    CurrencyConverter {
        id: currencyConverter
        anchors.fill: parent
    }


    // Here comes the TestCase
    TestCase {
        id: currentyConverterTest
        name: "CurrencyConverter"

        // We must wait until the window is shown because we're going to do mouse interaction
        when: windowShown


        // Because this app needs to fetch data from the internet on startup, we need to
        // wait for it to be done before we can do some currency conversions.
        function initTestCase() {

            // get the activity indicator and wait for it to stop running.
            // As we wait for everything to be built up with "when: windowShowd" above,
            // we can safely assume loading has started already.
            var activityIndicator = Helpers.findChild(currencyConverter, "activityIndicator")
            tryCompare(activityIndicator, "running", false)
        }


        // Lets test if the clear button works
        function test_clearButton() {
            var inputFrom = Helpers.findChild(currencyConverter, "inputFrom")
            var inputTo = Helpers.findChild(currencyConverter, "inputTo")

            // Click in the middle of the inputFrom TextField to focus it
            mouseClick(inputFrom, inputFrom.width / 2, inputFrom.height / 2)

            // Press Key "5"
            keyClick(Qt.Key_5)

            // Now the field should contain the value 0.05 because 0.0 is already in there in the beginning
            tryCompare(inputFrom, "text", "0.05", "Input field \"From:\" does does not contain the value 0.05")

            var clearBtn = Helpers.findChild(currencyConverter, "clearBtn")
            mouseClick(clearBtn, clearBtn.width / 2, clearBtn.height / 2)
            
            // Now the field should be set back to "0.0"
            tryCompare(inputFrom, "text", "0.0", "Input field \"From:\" is not reset to 0.00")
        }


        // In case we have the same test to be run multiple times with different input data,
        // we can provide a _data() function that returns the test sets.
        // Must be the same name as the test function with _data appended.
        function test_convert_data() {
            return [
                { tag: "0", inputKey: Qt.Key_0, value: 0 },
                { tag: "5", inputKey: Qt.Key_5, value: 5 }
            ]
        }

        // To actually use the _data function we add a parameter called data here.
        // The test function will be called for each data set and "data" contains
        // one row of the set.
        function test_convert(data) {
            var inputFrom = Helpers.findChild(currencyConverter, "inputFrom")
            var inputTo = Helpers.findChild(currencyConverter, "inputTo")

            // Click in the middle of the inputFrom TextField to focus it
            mouseClick(inputFrom, inputFrom.width / 2, inputFrom.height / 2)

            // Click at the right end of the inputFrom TextField to clear it
            mouseClick(inputFrom, inputFrom.width - units.gu(1), inputFrom.height / 2)

            // Press key from data set
            keyClick(data.inputKey)

            // Now the field should contain the value from the data set
            // compare() also checks the type. We need to convert text to int if the data set holds ints.
            compare(parseInt(inputFrom.text), data.value)

            // The output field should be 0 when the input is 0, otherwise it should be greater than 0
            if (data.value == 0) {
                // Here we compare the text to the string "0"
                compare(inputTo.text, "0", "0 Euros is not 0 Dollars!?!?")
            } else {
                // With verify() automatic casting can happen.
                verify(inputTo.text > 0)
            }
        }
    }
}
