import QtQuick 2.0
import QtTest 1.0
import "helpers.js" as Helpers
import "../.."
import QtQuick.XmlListModel 2.0

// Part 1

// This is a testcase that can just test functions, without painting something
// in the GUI. Lets test the function convert().
// You can run this test with:
// qmltestrunner -input tst_convert.qml

TestCase {
    name: "convert"

    // The element we want to test. As we are not painting
    // anything, don't bother with the size.
    CurrencyConverter {
        id: currencyConverter
    }

    // Because this app needs to fetch data from the internet on startup, we need to
    // wait for it to be done before we can do some currency conversions.
    // initTestCase() is executed in the beginning, before all test functions
    function initTestCase() {
        // Get the activityIndicator from the page and wait for it start running.
        // That means, the rates are being downloaded from the internet."
        // tryCompare() waits for up to 5 seconds for it to happen
        var activityIndicator = Helpers.findChild(currencyConverter, "activityIndicator")
        tryCompare(activityIndicator, "running", true)

        // Now that we know that the rates are being downloaded, wait for the activityIndicator to stop.
        tryCompare(activityIndicator, "running", false)
    }

    // Test functions must start with test_
    function test_convert0() {
        // Converting 0 form Euro to Dollars
        var value = currencyConverter.convert("0", 0, 1)

        // Hopefully 0 Euros will always be 0 Dollars
        // Compare() takes two values and a string that gets printed in case the two values don't match.
        compare(value, 0, "0 Euros is not 0 Dollars?!?! Run to the exchange office now!")
    }

    function test_convert1() {
        // convert 1.00 from currency 5 to currency 10
        var value = currencyConverter.convert("1.00", 5, 10)

        // Unfortunately we don't know the current currency rate, so lets just
        // make sure there actually is a result and it is greater 0
        // verify() just evaluates one boolean expression. Its the most flexible
        // one but unfortunately cannot print a nice error if it fails.
        verify(value > 0)
    }


    // Optional: cleaupTestCase() is executed at the end, after all test functions
    function cleanupTestCase() {
        print("All tests done. Nothing to cleanup")
    }

    // in case you need that you can have a init() and a cleanup(), that get
    // executed before and after each test function.
}
